@@ -1,11 +1,15 @@
 '''
 Module contains helper variables and functions for the MARBLE GUI application
 '''
+import os
 import time
 from multiprocessing import Process
 # The modules above are imported to create a setTimeout() [JS] like function in python
 # to be used to imitate the proces of a backend call
 
+# Define path to directory containing all images
+IMAGE_DIR_PATH = os.path.join("pymarble","frontend","static", "images")
+
 # Defining a dictionary of variable name suffixes
 VARIABLE_OPTIONS = {
   'BUTTON_ACTION': '_button_action',
@@ -30,9 +34,9 @@ COLOR_KEYS = {
 # Color profiles for UI
 STYLESHEET_CONSTS = {
   "colors": {
-    COLOR_KEYS["RED"]: "#d91309",
-    COLOR_KEYS["YELLOW"]: "#f4f72a",
-    COLOR_KEYS["GREEN"]: "#00ff0d"
+    COLOR_KEYS["RED"]: "#df3c3c",
+    COLOR_KEYS["YELLOW"]: "#f7f257",
+    COLOR_KEYS["GREEN"]: "#83df50"
   },
   "size": {
     "radio": 20,
@@ -44,14 +48,12 @@ STYLESHEET_CONSTS = {
 
 # Section Type
 DTYPE_TO_COLOR = {
-  "c": "#fdefef",
-  #"i": "TEXT METADATA(i)",
-  "d": "#efeffe",
-  "f": "#efeffe",
-  #"B": "PRIMARY DATA(B)",
-  "b": "#fcfcfc",
-  "B": "#fcfcfc",
-  "i": "#dedede"
+  "b": ["#e5e5e5","#cccccc"],
+  "c": ["#e5fdff","#65aeb5"],
+  "d": ["#eaeafe","#877bd1"],
+  "f": ["#eaeafe","#877bd1"],
+  "i": ["#9a031e","#9a031e"],
+  "B": ["#9a031e","#9a031e"]
 }
 
 # Color-probability map
@@ -86,17 +88,27 @@ def createStyleSheet(element, props):
     style = '''
     QRadioButton::indicator {{
       border: {border}px solid black;
-      height: {size}px;
+      height: {height}px;
       width: {size}px;
-      border-radius: {radius}px;
     }}
     QRadioButton::indicator:checked {{
       background: {color};
     }}
     '''.format(size=radioSize - radioBorder * 2,
                border=radioBorder,
-               radius=radioSize//2,
+               height=(radioSize - radioBorder * 2)*2,
                color=radioColor)
+  elif element == 'groupbox':
+    style = '''
+    QGroupBox {{
+    background-color: {background_color};
+    border: 1px solid {border_color};
+    border-left: {flag_width}px solid {flag_color};
+    }}
+    '''.format(flag_width=20,
+              background_color=DTYPE_TO_COLOR.get(props)[0],
+              flag_color=DTYPE_TO_COLOR.get(props)[1],
+              border_color=DTYPE_TO_COLOR.get(props)[1])
   return style
 
 # Imitating the time break of backend call
